function [ EHUFCO, EHUFSI ] = generateEncodingProcedureCodeTables( HUFFVAL, HUFFCODE, HUFFSIZE, LASTK )
%GENERATEENCODINGPROCEDURECODETABLES Creates the ordered table of Huffman codes and sizes for JPEG encoding
%
%   +EntropyCoding/generateEncodingProcedureCodeTables.m
%   Part of 'MATLAB Image & Video Compression Demos'
%
%   This method is called 'Order_codes' and specified in the JPEG standard
%   document. It simply creates a table to map symbol values to huffman
%   codes.
%
%   Ref: CCITT Rec. T.81 (1992 E) p. 53, Figure C.3
%
%   Parameters -
%       HUFFVAL: symbol values for each Huffman code
%       HUFFCODE: Huffman code values as generated by EntropyCoding.generateTableOfHuffmanCodes
%       HUFFSIZE: size in bits of each Huffman code as generated by EntropyCoding.generateTableOfHuffmanCodeSizes
%       LASTK: number of Huffman codes as generated by EntropyCoding.generateTableOfHuffmanCodeSizes
%   Returns -
%       EHUFCO: map of symbol value to Huffman code
%       EHUFSI: map of symbol value to Huffman code size
%
%   Licensed under the 3-clause BSD license, see 'License.m'
%   Copyright (c) 2011, Stephen Ierodiaconou, University of Bristol.
%   All rights reserved.

% FIXME: vectorise

K = 1;
conditionA = true;

while conditionA
    I = HUFFVAL(K);
    EHUFCO(I+1) = HUFFCODE(K);
    EHUFSI(I+1) = HUFFSIZE(K);
    K = K + 1;
    conditionA = (K < LASTK);
end 


end
